@@ -10,10 +10,10 @@ from path import Path
 
 
 class do(Action):
-    '''
+    """
     Do, do my work\n
     Do my dirty work, scapegoat\n
-    '''
+    """
 
     procs = []
 
@@ -26,7 +26,7 @@ class do(Action):
 @dataclass
 class web_screenshot(Action):
     url: str
-    use_mobile :bool=True
+    use_mobile: bool = True
 
     procs = [browser.web_screenshot]
 
@@ -34,6 +34,7 @@ class web_screenshot(Action):
 @dataclass
 class get_now_temp(Action):
     city: str
+    lang: str = "en"
     ascii_graphs: bool = True
     procs = [weather.get_weather, weather.ret_weather]
     # Should add something like this
