@@ -30,8 +30,8 @@ def web_screenshot(url: str, target: str = "./", use_mobile=True,**kwargs) -> st
         page.goto(url, wait_until="networkidle")
         # page.screenshot(path=f'./example-{browser_type.name}haha.png')
         target = Path(target) 
-        file_name = target/f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.png'
-        page.screenshot(path=file_name)
+        file_name = target/f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.jpeg'
+        page.screenshot(path=file_name,type="jpeg",quality=20)
         print(f"🤖 : DONE")
         print(f'The file is at {file_name}')
         browser.close()
