@@ -166,7 +166,7 @@ meme_list = [
 ]
 
 
-def get_meme(name: str, down: str, up: t.Optional[str] = None):
+def get_meme(name: str, down: str, up: t.Optional[str] = None, target: str = "./"):
 
     if name not in meme_list:
         raise Exception(f"Sorry we don't have meme pic named {name} yet.")
@@ -196,6 +196,9 @@ def get_meme(name: str, down: str, up: t.Optional[str] = None):
         raise Exception("One meme goes with two lines: Up and Down")
 
     with httpx.stream("GET", full) as r:
-        with open(f"{name}.jpg", 'wb+') as f:
+        full_name = f"{target}{name}.jpg"
+        with open(full_name, 'wb+') as f:
             for chunk in r.iter_bytes():
                 f.write(chunk)
+
+        return full_name
